@@ -360,6 +360,20 @@ sub _checkValues
                         $rc = LDAP_CONSTRAINT_VIOLATION;
                     }
                 }
+                if (defined($cattr->{lismunique})) {
+                    my $opts = $cattr->{lismopts};
+                    my $filter = "($opts->{attr}=$value)";
+                    if (defined($opts->{filter})) {
+                        $filter = "(&$filter$opts->{filter})";
+                    }
+                    my ($id) = ($dn =~ /^[^=]+=([^,]+),/);
+                    $filter =~ s/\%i/$id/g;
+                    my @vals = $self->_searchLism($opts, $filter);
+                    if (@vals && $vals[0]) {
+                        print $fd encode('utf8', "$timestamp: $attr=$value in $dn is invalid: value already exist in data\n");
+                        $rc = LDAP_CONSTRAINT_VIOLATION;
+                    }
+                }
             }
         }
     }
@@ -527,10 +541,12 @@ sub _updateCurrentEntries
             @list = ('REPLACE', $opts->{current}, $current);
         }
 
-        $rc = $self->{lism}->modify($base, @list);
-        if ($rc) {
-            $self->log(level => 'err', message => "modifying current number($base) failed($rc)");
-            return undef;
+        if (@list) {
+            $rc = $self->{lism}->modify($base, @list);
+            if ($rc) {
+                $self->log(level => 'err', message => "modifying current number($base) failed($rc)");
+                return undef;
+            }
         }
     }
 
@@ -576,9 +592,13 @@ sub _checkConfig
             }
 
             foreach my $cattr (keys %{$rule->{attr}}) {
-                if (defined($rule->{attr}{$cattr}->{lismexist})) {
+                if (defined($rule->{attr}{$cattr}->{lismexist}) || defined($rule->{attr}{$cattr}->{lismunique})) {
+                    if (defined($rule->{attr}{$cattr}->{lismopts})) {
+                        next;
+                    }
+                    my ($name) = keys %{$rule->{attr}{$cattr}};
                     my $lismopts = {};
-                    my ($base, $attr, $scope, $filter) = split(/\?/, $rule->{attr}{$cattr}->{lismexist}[0]);
+                    my ($base, $attr, $scope, $filter) = split(/\?/, $rule->{attr}{$cattr}->{$name}[0]);
                     $lismopts->{base} = $base;
                     $lismopts->{attr} = $attr;
                     if ($scope) {
